"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.Annotatable = void 0;
const Annotation_1 = require("./Annotation");
const Hashable_1 = require("./Hashable");
class Annotatable extends Hashable_1.Hashable {
    constructor() {
        super(...arguments);
        this.annotations = {};
    }
    createAnnotation(id, data) {
        if (this.hasAnnotation(id)) {
            const annotation = this.getAnnotation(id);
            annotation.data = data;
            return this.getAnnotation(id);
        }
        else {
            const annotation = this.createNewAnnotation(id, data, this);
            this.setAnnotation(annotation);
            return annotation;
        }
    }
    createNewAnnotation(id, data, parent = undefined) {
        return new Annotation_1.Annotation(id, data, parent);
    }
    setAnnotation(annotation) {
        this.annotations[annotation.id] = annotation;
    }
    hasAnnotation(id) {
        return this.annotations[id] != undefined;
    }
    getAnnotation(id) {
        return this.annotations[id];
    }
    getAnnotationData(id) {
        if (!this.hasAnnotation(id)) {
            throw new Error(`Annotation ${id} does not exist`);
        }
        return this.annotations[id].data;
    }
    getData(annotation) {
        if (this.annotations[annotation.id] == undefined) {
            throw new Error(`Annotation ${annotation.id} does not exist`);
        }
        return this.annotations[annotation.id].data;
    }
    cloneAnnotationsTo(annotatable) {
        for (const [key, value] of Object.entries(this.annotations)) {
            const annotation = annotatable.createAnnotation(key, value.data);
            delete annotation.parent;
        }
    }
    clearAnnotations() {
        this.annotations = {};
    }
    cloneTo(target) {
        this.cloneAnnotationsTo(target);
    }
}
exports.Annotatable = Annotatable;
//# sourceMappingURL=Annotatable.js.map