"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.EdgeType = exports.TransformationDirection = void 0;
const NamedElement_1 = require("./NamedElement");
// Controlflow transformation direction transforms from source to target nodes.
// Dependency transformation direction transforms from target to source nodes.
var TransformationDirection;
(function (TransformationDirection) {
    TransformationDirection[TransformationDirection["CONTROLFLOW"] = 0] = "CONTROLFLOW";
    TransformationDirection[TransformationDirection["DEPENDENCY"] = 1] = "DEPENDENCY";
})(TransformationDirection = exports.TransformationDirection || (exports.TransformationDirection = {}));
class EdgeType extends NamedElement_1.NamedElement {
    constructor(id, priority = 0) {
        super(id);
        this.transformationDirection = TransformationDirection.CONTROLFLOW;
        this.id = id;
        this.priority = priority;
        this.immediate = false;
    }
    clone() {
        const newType = new EdgeType(this.getId(), this.priority);
        newType.setImmediate(this.immediate);
        newType.setTransformationDirection(this.transformationDirection);
        this.cloneAnnotationsTo(newType);
        return newType;
    }
    equals(other) {
        return super.equals(other) &&
            this.getPriority() === other.getPriority() &&
            this.isImmediate() === other.isImmediate();
    }
    getId() {
        return this.id;
    }
    getPriority() {
        return this.priority;
    }
    setPriority(priority) {
        this.priority = priority;
        return this;
    }
    isImmediate() {
        return this.immediate;
    }
    setImmediate(immediate) {
        this.immediate = immediate;
        return this;
    }
    getTransformationDirection() {
        return this.transformationDirection;
    }
    setTransformationDirection(transformationDirection) {
        this.transformationDirection = transformationDirection;
        return this;
    }
}
exports.EdgeType = EdgeType;
//# sourceMappingURL=EdgeType.js.map