/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { Annotatable } from "./Annotatable";
import { IHGraph } from "./IHGraph";
import { SimpleNodeContent } from "./SimpleNode";
export type AnnotationFactoryType = {
    [key: string]: any;
};
export interface SourceNodeInterface {
    id: string;
    content?: SimpleNodeContent;
    annotations?: AnnotationFactoryType;
}
export interface EdgeTypeInterface {
    id: string;
    priority?: number;
    immediate?: boolean;
}
export interface EdgeInterface {
    edgeType: string;
    sourceNode: string;
    targetNode: string;
    annotations?: AnnotationFactoryType;
}
export interface IHGraphFactoryInterface {
    nodes: SourceNodeInterface[];
    edgeTypes: EdgeTypeInterface[];
    edges: EdgeInterface[];
    annotations?: AnnotationFactoryType;
}
export declare class SourceNodeFactoryClass extends Annotatable {
    id: string;
    content: SimpleNodeContent;
    constructor(id: string, content: SimpleNodeContent);
}
export declare class EdgeTypeFactoryClass extends Annotatable {
    id: string;
    priority: number;
    immediate: boolean;
    constructor(id: string, priority: number, immediate: boolean);
}
export declare class EdgeFactoryClass extends Annotatable {
    edgeType: string;
    sourceNode: string;
    targetNode: string;
    constructor(edgeType: string, sourceNode: string, targetNode: string);
}
export declare class FactoryObjectClass extends Annotatable {
    nodes: SourceNodeFactoryClass[];
    edgeTypes: EdgeTypeFactoryClass[];
    edges: EdgeFactoryClass[];
}
export declare function createIHGraphFromJSONString(json: string): IHGraph;
export declare function createIHGraphFromJSON(json: any): IHGraph;
