"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.createIHGraphFromJSON = exports.createIHGraphFromJSONString = exports.FactoryObjectClass = exports.EdgeFactoryClass = exports.EdgeTypeFactoryClass = exports.SourceNodeFactoryClass = void 0;
const Annotatable_1 = require("./Annotatable");
const IHGraph_1 = require("./IHGraph");
class SourceNodeFactoryClass extends Annotatable_1.Annotatable {
    constructor(id, content) {
        super();
        this.id = "";
        this.content = undefined;
        this.id = id;
        this.content = content;
    }
}
exports.SourceNodeFactoryClass = SourceNodeFactoryClass;
class EdgeTypeFactoryClass extends Annotatable_1.Annotatable {
    constructor(id, priority, immediate) {
        super();
        this.id = "";
        this.priority = 0;
        this.immediate = false;
        this.id = id;
        this.priority = priority;
        this.immediate = immediate;
    }
}
exports.EdgeTypeFactoryClass = EdgeTypeFactoryClass;
class EdgeFactoryClass extends Annotatable_1.Annotatable {
    constructor(edgeType, sourceNode, targetNode) {
        super();
        this.edgeType = "";
        this.sourceNode = "";
        this.targetNode = "";
        this.edgeType = edgeType;
        this.sourceNode = sourceNode;
        this.targetNode = targetNode;
    }
}
exports.EdgeFactoryClass = EdgeFactoryClass;
class FactoryObjectClass extends Annotatable_1.Annotatable {
    constructor() {
        super(...arguments);
        this.nodes = [];
        this.edgeTypes = [];
        this.edges = [];
    }
}
exports.FactoryObjectClass = FactoryObjectClass;
function createIHGraphFromJSONString(json) {
    const parsedJSON = JSON.parse(json);
    const ihGraph = new IHGraph_1.IHGraph();
    if (parsedJSON.annotations) {
        for (const [id, data] of Object.entries(parsedJSON.annotations)) {
            ihGraph.createAnnotation(id, data["data"]);
        }
    }
    // create nodes
    for (const node of parsedJSON.nodes) {
        const newNode = ihGraph.createSimpleNode(node.id);
        if (node.content) {
            newNode.setContent(node.content);
        }
        if (node.annotations) {
            for (const [id, data] of Object.entries(node.annotations)) {
                newNode.createAnnotation(id, data["data"]);
            }
        }
    }
    // create edge types
    for (const edgeType of parsedJSON.edgeTypes) {
        const edgeTypeObject = ihGraph.createEdgeType(edgeType.id, edgeType.priority);
        if (edgeType.immediate) {
            edgeTypeObject.setImmediate(true);
        }
        if (edgeType.annotations) {
            for (const [id, data] of Object.entries(edgeType.annotations)) {
                edgeTypeObject.createAnnotation(id, data["data"]);
            }
        }
    }
    // create edges
    for (const edge of parsedJSON.edges) {
        const sourceNode = ihGraph.getNodeById(edge.sourceNode);
        if (!sourceNode) {
            throw new Error(`Source node with id ${edge.sourceNode} does not exist.`);
        }
        const targetNode = ihGraph.getNodeById(edge.targetNode);
        if (!targetNode) {
            throw new Error(`Target node with id ${edge.targetNode} does not exist.`);
        }
        const edgeType = ihGraph.getEdgeTypeById(edge.edgeType);
        if (!edgeType) {
            throw new Error(`Edge type with id ${edge.type} does not exist.`);
        }
        const edgeObject = ihGraph.createTransformationEdge(edgeType, sourceNode, targetNode);
        if (edge.annotations) {
            for (const [id, data] of Object.entries(edge.annotations)) {
                edgeObject.createAnnotation(id, data["data"]);
            }
        }
    }
    return ihGraph;
}
exports.createIHGraphFromJSONString = createIHGraphFromJSONString;
function createIHGraphFromJSON(json) {
    return createIHGraphFromJSONString(JSON.stringify(json));
}
exports.createIHGraphFromJSON = createIHGraphFromJSON;
//# sourceMappingURL=IHFactory.js.map