"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleNode = exports.SimpleNodeStatus = void 0;
const NamedElement_1 = require("./NamedElement");
var SimpleNodeStatus;
(function (SimpleNodeStatus) {
    SimpleNodeStatus["UNDEFINED"] = "UNDEFINED";
    SimpleNodeStatus["SUCCESS"] = "SUCCESS";
    SimpleNodeStatus["WARNING"] = "WARNING";
    SimpleNodeStatus["ERROR"] = "ERROR";
})(SimpleNodeStatus = exports.SimpleNodeStatus || (exports.SimpleNodeStatus = {}));
class SimpleNode extends NamedElement_1.NamedElement {
    constructor(parent, id = "") {
        super(id);
        this.content = undefined;
        this.status = SimpleNodeStatus.UNDEFINED;
        this.incomingEdges = [];
        this.outgoingEdges = [];
        this.parent = parent;
        this.id = id;
    }
    clone(parent = null, edgeMapping = undefined) {
        const clone = new SimpleNode(parent ? parent : this.parent, this.id);
        for (const outgoingEdge of this.outgoingEdges) {
            const edgeClone = outgoingEdge.clone(clone);
            if (edgeMapping !== undefined) {
                edgeMapping.set(outgoingEdge, edgeClone);
            }
        }
        clone.content = this.content;
        clone.status = this.status;
        this.cloneAnnotationsTo(clone);
        return clone;
    }
    getParent() {
        return this.parent;
    }
    setParent(parent) {
        this.parent = parent;
    }
    getId() {
        return this.id;
    }
    getContent() {
        return this.content;
    }
    getContentAsString() {
        if (this.content == undefined) {
            return "";
        }
        return this.content;
    }
    setContent(content) {
        this.content = content;
    }
    appendContent(content) {
        if (this.content === undefined) {
            this.content = "";
        }
        this.content += content;
    }
    getStatus() {
        return this.status;
    }
    setStatus(status) {
        this.status = status;
    }
    getIncomingEdges() {
        return this.incomingEdges;
    }
    getOutgoingEdges() {
        return this.outgoingEdges;
    }
    addIncomingEdge(edge) {
        this.incomingEdges.push(edge);
    }
    addOutgoingEdge(edge) {
        this.outgoingEdges.push(edge);
    }
    removeIncomingEdge(edge) {
        this.incomingEdges = this.incomingEdges.filter((e) => e !== edge);
    }
    removeOutgoingEdge(edge) {
        this.outgoingEdges = this.outgoingEdges.filter((e) => e !== edge);
    }
}
exports.SimpleNode = SimpleNode;
//# sourceMappingURL=SimpleNode.js.map