"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const IHGraph_1 = require("../../src/IHGraph");
const EdgeType_1 = require("../../src/EdgeType");
const TransformationProcessor_1 = require("../../src/TransformationProcessor");
function testGraphSimple() {
    const thGraph = new IHGraph_1.IHGraph();
    const node1 = thGraph.createSimpleNode("Node1");
    const node2 = thGraph.createSimpleNode("Node2");
    const type1 = thGraph.createEdgeType("Type1", 1);
    thGraph.createTransformationEdge(type1, node1, node2);
    return thGraph;
}
class Sequence extends TransformationProcessor_1.TransformationProcessor {
}
test("transformationConfiguration", () => {
    const thGraph = testGraphSimple();
    thGraph.getTransformationConfiguration().set(thGraph.getEdgeTypes()[0], Sequence);
    expect(thGraph.getTransformationConfiguration().get(thGraph.getEdgeTypes()[0])).toBe(Sequence);
});
test("transformationConfigurationById", () => {
    const thGraph = testGraphSimple();
    thGraph.getTransformationConfiguration().set(thGraph.getEdgeTypes()[0], Sequence);
    const edgeType = new EdgeType_1.EdgeType("Type1", 1);
    expect(thGraph.getTransformationConfiguration().get(edgeType))?.toBe(Sequence);
});
test("transformationConfigurationClone", () => {
    const thGraph = testGraphSimple();
    thGraph.getTransformationConfiguration().set(thGraph.getEdgeTypes()[0], Sequence);
    const edgeType = new EdgeType_1.EdgeType("Type1", 1);
    const clone = thGraph.clone();
    expect(Array.of(clone.getTransformationConfiguration().keys()).length).toBe(1);
    expect(clone.getTransformationConfiguration().get(edgeType)).toBe(Sequence);
});
//# sourceMappingURL=IHGraph.36.configuration.test.js.map