"use strict";
/********************************************************************************
 * Copyright (c) 2023 ssm.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const TestGraphs_1 = require("./TestGraphs");
const IHFactory_1 = require("../../src/IHFactory");
test("createIHGraphAnnotation01Primitives", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotation", "First Annotation");
    expect(graph.getAnnotationData("testAnnotation")).toBe("First Annotation");
});
test("createIHGraphAnnotation02Set", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotation", "First Annotation");
    graph.createAnnotation("testAnnotation", "Second Annotation");
    expect(graph.getAnnotationData("testAnnotation")).toBe("Second Annotation");
});
test("createIHGraphAnnotation03Objects", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotation", { x: 100, y: 200 });
    expect(graph.getAnnotationData("testAnnotation")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation04Retrieval", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotation", { x: 100, y: 200 });
    const annotation = graph.getAnnotation("testAnnotation");
    expect(annotation).toBeDefined();
    expect(annotation.get()).toEqual({ x: 100, y: 200 });
    annotation.set({ x: 200, y: 300 });
    expect(annotation.get()).toEqual({ x: 200, y: 300 });
    expect(graph.getAnnotationData("testAnnotation")).toEqual({ x: 200, y: 300 });
});
test("createIHGraphAnnotation05GenericRetrieval", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const annotation = graph.createAnnotation("testAnnotation", { x: 100, y: 200 });
    expect(annotation).toBeDefined();
    expect(annotation.get()).toEqual({ x: 100, y: 200 });
    annotation.set({ x: 200, y: 300 });
    expect(annotation.get()).toEqual({ x: 200, y: 300 });
    const data = graph.getData(annotation);
    const dataCompare = { x: 200, y: 300 };
    expect(data).toEqual(dataCompare);
});
test("createIHGraphAnnotation06Multiple", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotationString", "First Annotation");
    graph.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    expect(graph.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(graph.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation07SerializationGraph", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotationString", "First Annotation");
    graph.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const serialization = graph.serialize(true);
    expect(serialization).toBeDefined();
    expect(serialization).not.toBeNull();
    const factoryGraph = (0, IHFactory_1.createIHGraphFromJSONString)(serialization);
    expect(factoryGraph).toBeDefined();
    expect(factoryGraph.equals(graph)).toBeTruthy();
    expect(factoryGraph.annotations).toBeDefined();
    expect(factoryGraph.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(factoryGraph.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation08SerializationNode", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const node = graph.getNodes()[0];
    node.createAnnotation("testAnnotationString", "First Annotation");
    node.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const serialization = graph.serialize(true);
    expect(serialization).toBeDefined();
    expect(serialization).not.toBeNull();
    const factoryGraph = (0, IHFactory_1.createIHGraphFromJSONString)(serialization);
    expect(factoryGraph).toBeDefined();
    const factoryNode = factoryGraph.getNodes()[0];
    expect(factoryNode).toBeDefined();
    expect(factoryNode.annotations).toBeDefined();
    expect(factoryNode.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(factoryNode.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation09SerializationEdgeType", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const edgeType = graph.getEdgeTypes()[0];
    edgeType.createAnnotation("testAnnotationString", "First Annotation");
    edgeType.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const serialization = graph.serialize(true);
    expect(serialization).toBeDefined();
    expect(serialization).not.toBeNull();
    const factoryGraph = (0, IHFactory_1.createIHGraphFromJSONString)(serialization);
    expect(factoryGraph).toBeDefined();
    const factoryEdgeType = factoryGraph.getEdgeTypes()[0];
    expect(factoryEdgeType).toBeDefined();
    expect(factoryEdgeType.annotations).toBeDefined();
    expect(factoryEdgeType.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(factoryEdgeType.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation10SerializationEdge", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const edge = graph.getEdges()[0];
    edge.createAnnotation("testAnnotationString", "First Annotation");
    edge.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const serialization = graph.serialize(true);
    expect(serialization).toBeDefined();
    expect(serialization).not.toBeNull();
    const factoryGraph = (0, IHFactory_1.createIHGraphFromJSONString)(serialization);
    expect(factoryGraph).toBeDefined();
    const factoryEdge = factoryGraph.getEdges()[0];
    expect(factoryEdge).toBeDefined();
    expect(factoryEdge.annotations).toBeDefined();
    expect(factoryEdge.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(factoryEdge.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation11CloneGraph", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    graph.createAnnotation("testAnnotationString", "First Annotation");
    graph.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const clone = graph.clone();
    expect(clone).toBeDefined();
    expect(clone.equals(graph)).toBeTruthy();
    expect(clone.annotations).toBeDefined();
    expect(clone.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(clone.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation12CloneNode", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const node = graph.getNodes()[0];
    node.createAnnotation("testAnnotationString", "First Annotation");
    node.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const clone = graph.clone();
    expect(clone).toBeDefined();
    const cloneNode = clone.getNodes()[0];
    expect(cloneNode).toBeDefined();
    expect(cloneNode.annotations).toBeDefined();
    expect(cloneNode.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(cloneNode.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation13CloneEdgeType", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const edgeType = graph.getEdgeTypes()[0];
    edgeType.createAnnotation("testAnnotationString", "First Annotation");
    edgeType.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const clone = graph.clone();
    expect(clone).toBeDefined();
    const cloneEdgeType = clone.getEdgeTypes()[0];
    expect(cloneEdgeType).toBeDefined();
    expect(cloneEdgeType.annotations).toBeDefined();
    expect(cloneEdgeType.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(cloneEdgeType.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
test("createIHGraphAnnotation14CloneEdge", () => {
    const graph = (0, TestGraphs_1.testGraphSequence)();
    expect(graph).toBeDefined();
    const edge = graph.getEdges()[0];
    edge.createAnnotation("testAnnotationString", "First Annotation");
    edge.createAnnotation("testAnnotationObject", { x: 100, y: 200 });
    const clone = graph.clone();
    expect(clone).toBeDefined();
    const cloneEdge = clone.getEdges()[0];
    expect(cloneEdge).toBeDefined();
    expect(cloneEdge.annotations).toBeDefined();
    expect(cloneEdge.getAnnotationData("testAnnotationString")).toBe("First Annotation");
    expect(cloneEdge.getAnnotationData("testAnnotationObject")).toEqual({ x: 100, y: 200 });
});
//# sourceMappingURL=IHGraph.41.annotations.test.js.map